/******************************************************************************
;  *       @型号                 : MC51F7424
;  *       @创建日期             : 2023.02.09
;  *       @公司/作者            : SINOMCU.COM-AE
;  *       @晟矽微官网           : http://www.sinomcu.com/
;  *       @版权                 : 晟矽微电 版权所有.
;  *----------------------摘要描述---------------------------------
;  * uint16_t Get_ADCResult_SignalCh(uint8_t channel) 获取但通道转换结果;
;  * float ADC_GainGet(void) 获取ADC增益设置.
******************************************************************************/

#include "user_config.h"
#include "GPIO.h"
#include "ADC.h"

/**
  * @brief  one channel convert and get result
  * @param  uint8_t channel can be one of following values:
  *         @arg @ref ADC_Channel_AN0
  *         @arg @ref ADC_Channel_AN1
  *         @arg @ref ADC_Channel_AN2
  *         @arg @ref ADC_Channel_AN3
  *         @arg @ref ADC_Channel_AN4
  *         @arg @ref ADC_Channel_AN5
  *         @arg @ref ADC_Channel_AN6
  *         @arg @ref ADC_Channel_AN7
  *         @arg @ref ADC_Channel_AN8
  *         @arg @ref ADC_Channel_AN9
  *         @arg @ref ADC_Channel_AN10
  *         @arg @ref ADC_Channel_OP0OUT
  *         @arg @ref ADC_Channel_Tmp
  *         @arg @ref ADC_Channel_LDO1P5
  *         @arg @ref ADC_Channel_VREF
  *         @arg @ref ADC_Channel_GND
  * @retval uint16_t ADC result
  */ 
uint16_t Get_ADCResult_SignalCh(uint8_t channel) {
  uint16_t adc_value=0;

  ADC_Channel_Set(channel);

  Start_ADC_Convert();
  while(Get_ADC_ConverState() ==ADC_ONGOING) {;}
  Clear_ADC_IF();

  adc_value =Get_ADC_ADRValue();
  return adc_value;
}

/**
  * @brief  get ADC Gain set value;
  * @param  
  * @retval float,can be one of following values:
  *         @arg @ref 1
  *         @arg @ref 0.75
  *         @arg @ref 0.5
  *         @arg @ref 0.25
  */ 
float ADC_GainGet(void) {
  float ADCGainValue=0;
  switch(ADC_Gain_Get()) {
    case ADC_GAIN_1:
      ADCGainValue =1;
      break;
    case ADC_GAIN_0P75:
      ADCGainValue =0.75;
      break;
    case ADC_GAIN_0P5:
      ADCGainValue =0.5;
      break;
    case ADC_GAIN_0P25:
      ADCGainValue =0.25;
      break;
  }
  return ADCGainValue;
}

/******************************** END OF FILE *********************************/